//========================================================================//
//         SOURCE CODE LICENSE                                            //
//  Copyright 2012 Dassault Systmes SolidWorks Corporation               //
//  All rights reserved.                                                  //
//  This software and related documentation are proprietary to            // 
//  Dassault Systmes SolidWorks Corporation                              //
//========================================================================//
// dsTolerance_c.h, C++ API dsTolerance_c interface
//

#pragma once

#include "dsinterface_global.h"
#include "dsInterfaceDefs.h"
#include "dsConstants.h"
#include "dsObject.h"
#include "dsString.h"

class dsTolerance_p;
class dsTolerance;
class dsColor_c;
class dsDimensionStyle_c;
class dsCustomData_c;
class dsHyperLink_c;
class dsMathVector_c;
class dsDimensionStyleUserData_c;
class dsDictionary_c;
class dsTransparency_c;

class DSINTERFACE_EXPORT dsTolerance_c : public dsObject
{
	DECLARE_DSCPP_INTERFACE(dsTolerance)
public:
	DSRESULT IsSame(dsTolerance_c* dsObj);

	DSRESULT get_Layer(dsString* Val);
	DSRESULT put_Layer(const dsString& NewVal);
	DSRESULT get_LineStyle(dsString* Val);
	DSRESULT put_LineStyle(const dsString& NewVal);
	DSRESULT get_LineScale(double* Val);
	DSRESULT put_LineScale(double NewVal);
	DSRESULT get_LineWeight(dsLineWeight_e* Val);
	DSRESULT put_LineWeight(dsLineWeight_e NewVal);	
	DSRESULT get_Visible(bool* Val);
	DSRESULT put_Visible(bool NewVal);
	DSRESULT Select(bool SelectFlag, bool* Res);
	DSRESULT get_Color(dsColor_c ** Val);
	DSRESULT put_Color(dsColor_c * NewVal);
	DSRESULT get_Erased(bool * Val);
	DSRESULT put_Erased(bool  NewVal);

	DSRESULT get_DimensionStyle(dsString*  Val);
	DSRESULT put_DimensionStyle(const dsString&  NewVal);
	DSRESULT GetDimensionStyleData(dsDimensionStyle_c ** DimensionStyle);
	DSRESULT GetPosition(double * X, double * Y, double * Z);
	DSRESULT SetPosition(double  X, double  Y, double  Z);
	DSRESULT get_Text(dsString*  Val);
	DSRESULT put_Text(const dsString&  NewVal);
	DSRESULT get_TextColor(dsColor_c ** Val);
	DSRESULT put_TextColor(dsColor_c * NewVal);
	DSRESULT get_TextHeight(double * Val);
	DSRESULT put_TextHeight(double  NewVal);
	DSRESULT get_TextStyle(dsString*  Val);
	DSRESULT put_TextStyle(const dsString&  NewVal);
	DSRESULT get_DimensionScaleFactor(double * Val);
	DSRESULT put_DimensionScaleFactor(double  NewVal);
	DSRESULT get_DimensionLineColor(dsColor_c ** Val);
	DSRESULT put_DimensionLineColor(dsColor_c * NewVal);
	DSRESULT GetCustomData(const dsString&  ApplicationName, dsCustomData_c ** CustomData);
	DSRESULT SetCustomData(const dsString&  ApplicationName, dsCustomData_c * CustomData);
	DSRESULT DeleteCustomData(const dsString&  ApplicationName);
	DSRESULT get_Handle(dsString*  Val);
	DSRESULT GetHyperLink(dsHyperLink_c ** HyperLink);
	DSRESULT SetHyperLink(dsHyperLink_c * HyperLink);
	DSRESULT DeleteHyperLink( );
	DSRESULT GetBoundingBox(double * X1, double * Y1, double * Z1, double * X2, double * Y2, double * Z2);
	DSRESULT GetNormal(dsMathVector_c ** Normal);
	DSRESULT GetDimensionStyleUserData(dsDimensionStyleUserData_c ** DimensionStyleUserData);
	DSRESULT CreateExtensionDictionary(dsDictionary_c ** Dictionary);
	DSRESULT GetExtensionDictionary(dsDictionary_c ** Dictionary);
	DSRESULT ReleaseExtensionDictionary(bool * Result);
	DSRESULT get_PrintStyle(dsString*  Val);
	DSRESULT put_PrintStyle(const dsString&  NewVal);
	DSRESULT get_Transparency(dsTransparency_c ** Val);
	DSRESULT put_Transparency(dsTransparency_c * NewVal);
};
